@@ -1,29 +1,27 @@
 OC.L10N.register(
     "deck",
     {
-    "Hours" : "Saatlar",
-    "Minutes" : "Dəqiqələr",
     "Personal" : "Şəxsi",
     "Done" : "Done",
     "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Yüklənilən faylın həcmi HTML formasinda olan MAX_FILE_SIZE direktivində təyin dilmiş həcmi aşır.",
     "No file was uploaded" : "Heç bir fayl yüklənilmədi",
     "Missing a temporary folder" : "Müvəqqəti qovluq çatışmır",
-    "Actions" : "İşlər",
-    "Close" : "Bağla",
+    "Cancel" : "Dayandır",
+    "Details" : "Detallar",
     "Sharing" : "Paylaşılır",
     "Tags" : "Işarələr",
-    "Group" : "Qrup",
-    "Loading" : "Loading",
+    "Can edit" : "Can edit",
+    "Can share" : "Can share",
+    "Delete" : "Sil",
     "Edit" : "Dəyişiklik et",
-    "Share" : "Paylaş",
-    "Create" : "Yarat",
-    "Title" : "Başlıq",
-    "Cancel upload" : "Yüklənməni dayandır",
-    "by" : "onunla",
-    "Modified:" : "Dəyişdirildi:",
-    "Created:" : "Yaradıldı:",
     "Description" : "Açıqlanma",
-    "Saved" : "Saxlanıldı",
-    "Settings" : "Quraşdırmalar"
+    "Modified" : "Dəyişdirildi",
+    "Save" : "Saxla",
+    "Reply" : "Cavab",
+    "Update" : "Yenilənmə",
+    "(group)" : "(qrup)",
+    "seconds ago" : "saniyələr öncə",
+    "Settings" : "Quraşdırmalar",
+    "Share" : "Paylaş"
 },
 "nplurals=2; plural=(n != 1);");
