@@ -1,29 +1,27 @@
 OC.L10N.register(
     "deck",
     {
-    "Hours" : "ঘন্টা",
-    "Minutes" : "মিনিট",
     "Personal" : "ব্যক্তিগত",
     "Done" : "Done",
     "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "আপলোড করা ফাইলটি  HTML  ফর্মে উল্লিখিত MAX_FILE_SIZE নির্ধারিত ফাইলের সর্বোচ্চ আকার  অতিক্রম করতে চলেছে ",
     "No file was uploaded" : "কোন ফাইল আপলোড করা হয় নি",
     "Missing a temporary folder" : "অস্থায়ী ফোল্ডারটি হারানো গিয়েছে",
-    "Actions" : "পদক্ষেপসমূহ",
-    "Close" : "বন্ধ",
+    "Cancel" : "বাতির",
+    "Details" : "বিসতারিত",
     "Sharing" : "ভাগাভাগিরত",
     "Tags" : "ট্যাগ",
-    "Group" : "গোষ্ঠীসমূহ",
-    "Loading" : "Loading",
+    "Can edit" : "Can edit",
+    "Can share" : "Can share",
+    "Delete" : "মুছে",
     "Edit" : "সম্পাদনা",
-    "Share" : "ভাগাভাগি কর",
-    "Create" : "তৈরী কর",
-    "Title" : "শিরোনাম",
-    "Cancel upload" : "আপলোড বাতিল কর",
-    "by" : "কর্তৃক",
-    "Modified:" : "পরিবর্তিতঃ",
-    "Created:" : "তৈরীর নির্ঘন্টঃ",
     "Description" : "বিবরণ",
-    "Saved" : "সংরক্ষণ করা হলো",
-    "Settings" : "সেটিংস"
+    "Modified" : "পরিবর্তিত",
+    "Save" : "সংরক্ষণ",
+    "Reply" : "জবাব",
+    "Update" : "পরিবর্ধন",
+    "(group)" : "(গোষ্ঠি)",
+    "seconds ago" : "সেকেন্ড পূর্বে",
+    "Settings" : "সেটিংস",
+    "Share" : "ভাগাভাগি কর"
 },
 "nplurals=2; plural=(n != 1);");
