@@ -1,30 +1,24 @@
 OC.L10N.register(
     "deck",
     {
-    "Hours" : "Sati",
-    "Minutes" : "Minute",
-    "Maximum file size of {size} exceeded" : "Maksimalna veličina datoteke prekoračena",
     "Personal" : "Osobno",
     "Done" : "Done",
     "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Učitana datoteka premašuje maksimalnu dopuštenu veličinu datoteke MAX_FILE_SIZE navedenu u HTML formi",
     "No file was uploaded" : "Nijedna datoteka nije učitana.",
     "Missing a temporary folder" : "Nedostaje privremeni direktorij.",
-    "Actions" : "Radnje",
-    "Close" : "Zatvori",
+    "Cancel" : "Otkaži",
     "Sharing" : "Dijeljenje",
-    "Group" : "Grupa",
-    "Circle" : "Krug",
-    "Loading" : "Loading",
+    "Can edit" : "Can edit",
+    "Can share" : "Can share",
+    "Delete" : "Obriši",
     "Edit" : "Izmjeni",
-    "Share" : "Podjeli",
-    "Create" : "Ustvari",
-    "Status" : "Status",
-    "Title" : "Naslov",
-    "Members" : "Članovi",
-    "Cancel upload" : "Prekini učitavanje",
-    "by" : "od strane",
     "Description" : "Opis",
-    "Saved" : "Spremljeno",
-    "Settings" : "Podešavanje"
+    "Comments" : "Komentari",
+    "Modified" : "Izmijenjeno",
+    "Save" : "Spremi",
+    "Update" : "Ažuriraj",
+    "Settings" : "Podešavanje",
+    "Share" : "Podjeli",
+    "Maximum file size of {size} exceeded" : "Maksimalna veličina datoteke prekoračena"
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
