@@ -153,6 +153,8 @@ OC.L10N.register(
     "Edit" : "Upravit",
     "Add a new tag" : "Přidat nový štítek",
     "title and color value must be provided" : "je třeba zadat nadpis a zvolit barvu",
+    "Title" : "Nadpisu",
+    "Members" : "Členové",
     "Add this attachment" : "Přidat tuto přílohu",
     "Delete Attachment" : "Smazat přílohu",
     "Restore Attachment" : "Obnovit přílohu",
@@ -185,12 +187,13 @@ OC.L10N.register(
     "Update" : "Aktualizovat",
     "(group)" : "(skupina)",
     "(circle)" : "(okruh)",
+    "seconds ago" : "před několika sekundami",
     "Assign to me" : "Přiřadit mě",
     "Delete card" : "Smazat kartu",
     "Move card" : "Přesunout kartu",
     "Card details" : "Podrobnosti o kartě",
+    "Move card to another board" : "Přesunout kartu na jinou tabuli",
     "Select a stack" : "Vybrat sloupec",
-    "seconds ago" : "před několika sekundami",
     "All boards" : "Všechny tabule",
     "Archived boards" : "Archivované tabule",
     "Shared boards" : "Sdílené tabule",
