@@ -6,22 +6,22 @@ OC.L10N.register(
     "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Mae'r ffeil lwythwyd i fyny'n fwy na chyfarwyddeb MAX_FILE_SIZE bennwyd yn y ffurflen HTML",
     "No file was uploaded" : "Ni lwythwyd ffeil i fyny",
     "Missing a temporary folder" : "Plygell dros dro yn eisiau",
-    "Actions" : "Gweithredoedd",
-    "Close" : "Cau",
+    "Cancel" : "Diddymu",
+    "Details" : "Manylion",
     "Tags" : "Tagiau",
-    "Group" : "Grŵp",
-    "Loading" : "Llwytho",
+    "Undo" : "Dadwneud",
+    "Can edit" : "Can edit",
+    "Can share" : "Can share",
+    "Delete" : "Dileu",
     "Edit" : "Golygu",
-    "Share" : "Rhannu",
-    "Create" : "Creu",
-    "Title" : "Teitl",
-    "Cancel upload" : "Diddymu llwytho i fyny",
-    "by" : "gan",
-    "Modified:" : "Addaswyd:",
-    "Created:" : "Crewyd:",
     "Description" : "Disgrifiad",
-    "Saved" : "Wedi'u cadw",
+    "Modified" : "Addaswyd",
     "Upload attachment" : "Llwytho atodiad",
-    "Settings" : "Gosodiadau"
+    "Save" : "Cadw",
+    "Update" : "Diweddaru",
+    "seconds ago" : "eiliad yn ôl",
+    "Settings" : "Gosodiadau",
+    "Share" : "Rhannu",
+    "An error occurred" : "Digwyddodd gwall"
 },
 "nplurals=4; plural=(n==1) ? 0 : (n==2) ? 1 : (n != 8 && n != 11) ? 2 : 3;");
