@@ -33,6 +33,8 @@ OC.L10N.register(
     "Delete list" : "Slet liste",
     "Add card" : "Tilføj kort",
     "Edit" : "Redigér",
+    "Title" : "Titel",
+    "Members" : "Medlemmer",
     "Due date" : "Forfaldsdato",
     "Remove due date" : "Fjern forfaldsdato",
     "Description" : "Beskrivelse",
@@ -46,9 +48,9 @@ OC.L10N.register(
     "Reply" : "Besvar",
     "Update" : "Opdatér",
     "(group)" : "(gruppe)",
+    "seconds ago" : "sekunder siden",
     "Delete card" : "Slet kort",
     "Move card" : "Flyt kort",
-    "seconds ago" : "sekunder siden",
     "Archived boards" : "Arkiverede lister",
     "Shared boards" : "Delte lister",
     "Settings" : "Indstillinger",
