@@ -1,10 +1,6 @@
 OC.L10N.register(
     "deck",
     {
-    "Remove user from card" : "Eliminar usuario de la tarjeta",
-    "Hours" : "Horas",
-    "Minutes" : "Minutos",
-    "File already exists" : "El archivo ya existe",
     "Deck" : "Deck",
     "Personal" : "Personal",
     "The card \"%s\" on \"%s\" has reached its due date." : "La tarjeta \"%s\" en \"%s\" ha alacanzado su fecha de entrega",
@@ -23,64 +19,46 @@ OC.L10N.register(
     "Missing a temporary folder" : "Falta una carpeta temporal",
     "Could not write file to disk" : "No fue posible escribir a disco",
     "A PHP extension stopped the file upload" : "Una extensión de PHP detuvo la carga del archivo",
-    "A kanban style project and personal management tool for Nextcloud" : "Una herramienta de administración de proyectos y personal estilo kanban",
-    "Add a new stack" : "Agregar una nueva pila",
-    "Submit" : "Enviar",
+    "Create new board" : "Crear un nuevo tablero",
+    "Cancel" : "Cancelar",
+    "File already exists" : "El archivo ya existe",
+    "Do you want to overwrite it?" : "¿Deseas sobre escribirlo?",
+    "Filter by tag" : "Filtrar por etiqueta",
     "Show archived cards" : "Mostrar tarjetas archivadas",
-    "Hide archived cards" : "Ocultar tarjetas archivadas",
-    "All Boards" : "Todos los Tableros",
-    "Archived boards" : "Tableros archivados",
-    "Actions" : "Acciones",
-    "Enter a card title" : "Ingresa el título de la tarjeta",
-    "Add card" : "Agregar tarjeta",
-    "Close" : "Cerrar",
+    "Details" : "Detalles",
     "Sharing" : "Compartiendo",
     "Tags" : "Etiquetas",
-    "Select users or groups to share with" : "Selecciona los usuarios o grupos con los cuales compartir",
-    "Group" : "Grupo",
-    "Circle" : "Círculo",
-    "No matching user or group found." : "No se encontraron coincidencias de usuarios o grupos.",
-    "Loading" : "Cargando",
+    "Undo" : "Deshacer",
+    "Can edit" : "Puede editar",
+    "Can share" : "Puede compartir",
+    "Delete" : "Borrar",
+    "Add a new stack" : "Agregar una nueva pila",
+    "Add card" : "Agregar tarjeta",
     "Edit" : "Editar",
+    "Due date" : "Fecha de vencimiento",
+    "Remove due date" : "Eliminar fecha de expiración",
+    "Description" : "Descripción",
+    "Formatting help" : "Ayuda de formato",
+    "Attachments" : "Adjuntos",
+    "Comments" : "Comentarios",
+    "Modified" : "Modificado",
+    "Created" : "Creado",
+    "Upload attachment" : "Cargar adjunto",
+    "Save" : "Guardar",
+    "Reply" : "Responder",
+    "Update" : "Actualizar",
+    "(group)" : "(grupo)",
+    "seconds ago" : "hace segundos",
+    "Archived boards" : "Tableros archivados",
+    "Shared boards" : "Tableros compartidos",
+    "Settings" : "Configuraciones ",
+    "New board title" : "Nuevo título del tablero",
     "Share" : "Compartir",
-    "Manage" : "Administrar",
-    "Discard share" : "Descartar elemento compartido",
-    "Create" : "Crear",
-    "Create a new tag" : "Crear una nueva etiqueta",
-    "Status" : "Estatus",
-    "Title" : "Título",
-    "Members" : "Miembros",
-    "More actions" : "Más acciones",
     "Edit board" : "Editar el tablero",
+    "An error occurred" : "Ha ocurrido un error",
     "Archive board" : "Archivar tablero",
     "Unarchive board" : "Desarchivar tablero",
     "Delete board" : "Borrar tableros",
-    "Undo board deletion - Otherwise the board will be deleted during the next cronjob run." : "Deshacer borrado de tablero - De lo contrario el tablero se borrará durante la siguiente ejecución del cronjob. ",
-    "Create new board" : "Crear un nuevo tablero",
-    "New board title" : "Nuevo título del tablero",
-    "Cancel upload" : "Cancelar carga",
-    "by" : "por",
-    "Modified:" : "Modificado:",
-    "Created:" : "Creado:",
-    "Choose a tag" : "Elije una etiqueta",
-    "Add a tag" : "Agrega una etiqueta",
-    "Select tags" : "Selecciona las etiquetas",
-    "Assign users" : "Asingar usuarios",
-    "Choose a user to assign" : "Elige un usuario a asignar",
-    "Assign this card to a user" : "Asignar esta tarjeta al usuario",
-    "Due date" : "Fecha de vencimiento",
-    "Click to set" : "Da click aquí para establecer",
-    "Remove due date" : "Eliminar fecha de expiración",
-    "Description" : "Descripción",
-    "Attachments" : "Adjuntos",
-    "Saved" : "Guardado",
-    "Unsaved changes" : "Cambios no guardados",
-    "Formatting help" : "Ayuda de formato",
-    "Upload attachment" : "Cargar adjunto",
-    "Add a card description…" : "Agregar una descripción de tarjeta...",
-    "Shared boards" : "Tableros compartidos",
-    "Move board to archive" : "Mover el tablero al archivo",
-    "Create a new board" : "Crear un nuevo tablero",
-    "Settings" : "Configuraciones "
+    "Board details" : "Detalles del tablero"
 },
 "nplurals=2; plural=(n != 1);");
