@@ -99,6 +99,8 @@ OC.L10N.register(
     "Edit" : "עריכה",
     "Add a new tag" : "הוספת תגית חדשה",
     "title and color value must be provided" : "יש לספק כותרת וערך צבע",
+    "Title" : "תפקיד",
+    "Members" : "חברים",
     "Add this attachment" : "הוספת קובץ מצורף זה",
     "Delete Attachment" : "מחיקת קובץ מצורף",
     "Restore Attachment" : "שחזור קובץ מצורף",
@@ -131,12 +133,12 @@ OC.L10N.register(
     "Update" : "עדכון",
     "(group)" : "(קבוצה)",
     "(circle)" : "(מעגל)",
+    "seconds ago" : "לפני מספר שניות",
     "Assign to me" : "הקצאה אלי",
     "Delete card" : "מחיקת כרטיס לארכיון",
     "Move card" : "העברת כרטיס",
     "Card details" : "פרטי הכרטיס",
     "Select a stack" : "בחירת ערימה",
-    "seconds ago" : "לפני מספר שניות",
     "All boards" : "כל הלוחות",
     "Archived boards" : "לוחות שנשמרו בארכיון",
     "Shared boards" : "לוחות משותפים",
