@@ -1,8 +1,6 @@
 OC.L10N.register(
     "deck",
     {
-    "Hours" : "Horas",
-    "Minutes" : "Minutas",
     "Personal" : "Personal",
     "Finished" : "Finite",
     "To review" : "A revider",
@@ -12,27 +10,25 @@ OC.L10N.register(
     "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Le file incargate excede le directiva MAX_FILE_SIZE que esseva specificate in le formulario HTML",
     "No file was uploaded" : "Nulle file esseva incargate",
     "Missing a temporary folder" : "Il manca un dossier temporari",
-    "Actions" : "Actiones",
-    "Close" : "Clauder",
+    "Cancel" : "Cancellar",
+    "Details" : "Detalios",
     "Sharing" : "Compartente",
     "Tags" : "Etiquettas",
-    "Select users or groups to share with" : "Selectiona usatores o gruppos pro compartir",
-    "Group" : "Gruppo",
-    "No matching user or group found." : "Nulle usator o gruppo correspondente trovate.",
-    "Loading" : "Loading",
+    "Undo" : "Disfacer",
+    "Can edit" : "Can edit",
+    "Can share" : "Can share",
+    "Delete" : "Deler",
     "Edit" : "Modificar",
-    "Share" : "Compartir",
-    "Manage" : "Administrar",
-    "Create" : "Crear",
-    "Title" : "Titulo",
-    "Members" : "Membros",
-    "Cancel upload" : "Cancellar incarga",
-    "by" : "per",
-    "Modified:" : "Modificate:",
-    "Created:" : "Create:",
     "Description" : "Description",
     "Attachments" : "Attachamentos",
-    "Saved" : "Salveguardate",
-    "Settings" : "Configurationes"
+    "Comments" : "Commentarios",
+    "Modified" : "Modificate",
+    "Save" : "Salveguardar",
+    "Reply" : "Responder",
+    "Update" : "Actualisation",
+    "(group)" : "(gruppo)",
+    "seconds ago" : "secundas passate",
+    "Settings" : "Configurationes",
+    "Share" : "Compartir"
 },
 "nplurals=2; plural=(n != 1);");
