@@ -105,6 +105,12 @@ OC.L10N.register(
     "Do you want to overwrite it?" : "上書きしますか？",
     "Archived cards" : "カードをアーカイブ",
     "Filter by tag" : "タグによるフィルター",
+    "Filter by assigned user" : "割当ユーザーでフィルター",
+    "Filter by due date" : "期限でフィルター",
+    "Overdue" : "期限超過",
+    "Next 7 days" : "次の7日間",
+    "Next 30 days" : "次の30日間",
+    "No due date" : "期限なし",
     "Show archived cards" : "アーカイブされたカードを表示する",
     "Toggle compact mode" : "コンパクトモードの切り替え",
     "Details" : "詳細",
@@ -119,8 +125,11 @@ OC.L10N.register(
     "Can share" : "共有可能",
     "Delete" : "削除",
     "Add a new stack" : "新しいスタックを追加する",
+    "Delete list" : "リストを削除",
     "Add card" : "カードを追加",
     "Edit" : "編集",
+    "Title" : "タイトル",
+    "Members" : "メンバー",
     "Due date" : "期限",
     "Remove due date" : "期限を削除",
     "Description" : "説明",
@@ -134,9 +143,9 @@ OC.L10N.register(
     "Reply" : "返信",
     "Update" : "更新",
     "(group)" : "(グループ)",
+    "seconds ago" : "数秒前",
     "Delete card" : "カードを削除する",
     "Move card" : "カードの移動",
-    "seconds ago" : "数秒前",
     "Archived boards" : "アーカイブ済みのボード",
     "Shared boards" : "共有ボード",
     "Settings" : "設定",
