@@ -1,10 +1,6 @@
 OC.L10N.register(
     "deck",
     {
-    "Remove user from card" : "მომხმარებლის ბარათიდან ამოშლა",
-    "Hours" : "საათი",
-    "Minutes" : "წუთი",
-    "File already exists" : "ფაილი უკვე არსებობს",
     "Deck" : "დასტა",
     "Personal" : "პირადი",
     "The card \"%s\" on \"%s\" has reached its due date." : "ბარათმა \"%s\" \"%s\"-ზე მიაღწია დანიშნულ დროს.",
@@ -19,62 +15,44 @@ OC.L10N.register(
     "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "ატვირთული ფაილი აჭარბებს HTML ფორამაში მითითებულ MAX_FILE_SIZE დირექტივას",
     "No file was uploaded" : "ფაილი არ აიტვირთა",
     "Missing a temporary folder" : "დროებითი დირექტორია არ არსებობს",
-    "Add a new stack" : "დასტის დამატება",
-    "Submit" : "გაგზავნა",
+    "Create new board" : "ახალი დაფის შექმნა",
+    "Cancel" : "უარყოფა",
+    "File already exists" : "ფაილი უკვე არსებობს",
+    "Do you want to overwrite it?" : "გსურთ მისი გადაწერა?",
+    "Filter by tag" : "ფილტრი ტეგებით",
     "Show archived cards" : "არქივირებული ბარათების ჩვენება",
-    "Hide archived cards" : "არქივირებული ბარათების დამალვა",
-    "All Boards" : "ყველა დაფა",
-    "Archived boards" : "არქივირებული დაფები",
-    "Actions" : "მოქმედებები",
-    "Enter a card title" : "შეიყვანეთ ბარათის სახელწოდება",
-    "Add card" : "ბარათის დამატება",
-    "Close" : "დახურვა",
+    "Details" : "დეტალები",
     "Sharing" : "გაზიარება",
     "Tags" : "ტეგები",
-    "Select users or groups to share with" : "გასაზიარებლად აირჩიეთ მომხმარებლები ან ჯგუფები",
-    "Group" : "ჯგუფი",
-    "Circle" : "წრე",
-    "No matching user or group found." : "მომხმარებლები ან ჯგუფები ვერ იქნა ნაპოვნი.",
-    "Loading" : "იტვირთება",
+    "Undo" : "დაბრუნება",
+    "Can edit" : "შეუძლია შეცვალოს",
+    "Can share" : "შეუძლია გააზიაროს",
+    "Delete" : "წაშლა",
+    "Add a new stack" : "დასტის დამატება",
+    "Add card" : "ბარათის დამატება",
     "Edit" : "შეცვლა",
+    "Due date" : "დროისთვის",
+    "Remove due date" : "მოაშორეთ დანიშნულების დრო",
+    "Description" : "აღწერა",
+    "Formatting help" : "დახმარება ფორმატირებაზე",
+    "Comments" : "კომენტარები",
+    "Modified" : "შეიცვალა",
+    "Created" : "შექმნილია",
+    "Upload attachment" : "დანართის ატვირთვა",
+    "Save" : "შენახვა",
+    "Reply" : "პასუხი",
+    "Update" : "განახლება",
+    "(group)" : "(ჯგუფი)",
+    "seconds ago" : "წამის წინ",
+    "Archived boards" : "არქივირებული დაფები",
+    "Shared boards" : "გაზიარებული დაფები",
+    "Settings" : "პარამეტრები",
+    "New board title" : "ახალი დაფის სახელი",
     "Share" : "გაზიარება",
-    "Manage" : "მენეჯმენტი",
-    "Discard share" : "გაზიარების უარყოფა",
-    "Create" : "შექმნა",
-    "Create a new tag" : "ახალი ტეგის შექმნა",
-    "Status" : "სტატუსი",
-    "Title" : "სათაური",
-    "Members" : "წევრები",
-    "More actions" : "მეტი ქმედება",
     "Edit board" : "დაფის შეცვლა",
     "Archive board" : "დაფის არქივირება",
     "Unarchive board" : "დაფის ამოღება",
     "Delete board" : "დაფის გაუქმება",
-    "Undo board deletion - Otherwise the board will be deleted during the next cronjob run." : "დაფის გაუქმების უკუგდება - სხვა შემთხვევაში დაფა შემდეგი conjob-ის გაშვებისას წაიშლება.",
-    "Create new board" : "ახალი დაფის შექმნა",
-    "New board title" : "ახალი დაფის სახელი",
-    "Cancel upload" : "ატვირთვის შეჩერება",
-    "by" : "შემქმნელი",
-    "Modified:" : "შეცვლილია:",
-    "Created:" : "შექმნილია:",
-    "Choose a tag" : "აირჩიეთ ტეგი",
-    "Add a tag" : "დაამატეთ ტეგი",
-    "Select tags" : "აირჩიეთ ტეგები",
-    "Assign users" : "დანიშნეთ მოხმარებლები",
-    "Choose a user to assign" : "აირჩიეთ მომხმარებელი",
-    "Assign this card to a user" : "დაუნიშნეთ ეს ბარათი მომხმარებელს",
-    "Due date" : "დროისთვის",
-    "Click to set" : "დააწკაპუნეთ დასაყენებლად",
-    "Remove due date" : "მოაშორეთ დანიშნულების დრო",
-    "Description" : "აღწერა",
-    "Saved" : "შენახულია",
-    "Unsaved changes" : "შეუნახავი ცვლილებები",
-    "Formatting help" : "დახმარება ფორმატირებაზე",
-    "Upload attachment" : "დანართის ატვირთვა",
-    "Add a card description…" : "დაამატეთ ბარათის აღწერილობა...",
-    "Shared boards" : "გაზიარებული დაფები",
-    "Move board to archive" : "დაფის არქვიში გადატანა",
-    "Create a new board" : "ახალი დაფის შექმნა",
-    "Settings" : "პარამეტრები"
+    "Board details" : "დაფის დეტალები"
 },
 "nplurals=2; plural=(n!=1);");
