@@ -1,29 +1,27 @@
 OC.L10N.register(
     "deck",
     {
-    "Hours" : "Stonnen",
-    "Minutes" : "Minutten",
     "Personal" : "Perséinlech",
     "Done" : "Done",
     "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Déi ropgelueden Datei ass méi grouss wei d'MAX_FILE_SIZE Eegenschaft déi an der HTML form uginn ass",
     "No file was uploaded" : "Et ass kee Fichier ropgeluede ginn",
     "Missing a temporary folder" : "Et feelt en temporären Dossier",
-    "Actions" : "Aktiounen",
-    "Close" : "Zoumaachen",
+    "Cancel" : "Ofbriechen",
+    "Details" : "Detailer",
     "Sharing" : "Gedeelt",
     "Tags" : "Tags",
-    "Group" : "Grupp",
-    "Loading" : "Loading",
+    "Can edit" : "Can edit",
+    "Can share" : "Can share",
+    "Delete" : "Läschen",
     "Edit" : "Änneren",
-    "Share" : "Deelen",
-    "Create" : "Erstellen",
-    "Title" : "Titel",
-    "Cancel upload" : "Eroplueden ofbriechen",
-    "by" : "vun",
-    "Modified:" : "Geännert:",
-    "Created:" : "Erstallt:",
     "Description" : "Beschreiwung",
-    "Saved" : "Gespäichert",
-    "Settings" : "Astellungen"
+    "Comments" : "Kommentarer",
+    "Modified" : "Geännert",
+    "Save" : "Späicheren",
+    "Reply" : "Äntwerten",
+    "Update" : "Update",
+    "seconds ago" : "Sekonnen hier",
+    "Settings" : "Astellungen",
+    "Share" : "Deelen"
 },
 "nplurals=2; plural=(n != 1);");
