@@ -18,6 +18,8 @@ OC.L10N.register(
     "Can share" : "Can share",
     "Delete" : "Устгах",
     "Edit" : "Засварлах",
+    "Title" : "Цол/Албан тушаал",
+    "Members" : "Гишүүд",
     "Description" : "Тайлбар",
     "Attachments" : "Хавсралт",
     "Comments" : "Сэтгэгдлүүд",
