@@ -31,6 +31,8 @@ OC.L10N.register(
     "Add a new stack" : "Adicionar nova pilha",
     "Add card" : "Adicionar um cartão",
     "Edit" : "Editar",
+    "Title" : "Título",
+    "Members" : "Membros",
     "Due date" : "Data limite",
     "Description" : "Descrição",
     "Attachments" : "Anexos",
@@ -41,8 +43,8 @@ OC.L10N.register(
     "Reply" : "Resposta",
     "Update" : "Atualizar",
     "(group)" : "(grupo)",
-    "Delete card" : "Eliminar cartão",
     "seconds ago" : "segundos atrás",
+    "Delete card" : "Eliminar cartão",
     "Archived boards" : "Quadros arquivados",
     "Settings" : "Definições",
     "New board title" : "Novo título de quadro",
