@@ -146,6 +146,8 @@ OC.L10N.register(
     "Add a new card" : "Dodaj novo nalogo",
     "Edit" : "Uredi",
     "title and color value must be provided" : "navedena morata biti podatka naslova in barve",
+    "Title" : "Naslov",
+    "Members" : "Člani",
     "Delete Attachment" : "Izbriši prilogo",
     "Restore Attachment" : "Obnovi prilogo",
     "Assign a tag to this card…" : "Dodeli oznako nalogi ...",
@@ -173,12 +175,12 @@ OC.L10N.register(
     "Update" : "Posodobi",
     "(group)" : "(skupina)",
     "(circle)" : "(krog)",
+    "seconds ago" : "pred nekaj sekundami",
     "Assign to me" : "Nalogo dodeli meni",
     "Delete card" : "Izbriši nalogo",
     "Move card" : "Premakni nalogo",
     "Card details" : "Podrobnosti naloge",
     "Select a stack" : "Izbor paketa nalog",
-    "seconds ago" : "pred nekaj sekundami",
     "All boards" : "Vse zbirke",
     "Archived boards" : "Arhivirane zbirke",
     "Shared boards" : "Zbirke v souporabi",
