@@ -121,6 +121,7 @@ OC.L10N.register(
     "Filter by assigned user" : "Filtrera efter tilldelad användare",
     "Filter by due date" : "Filtrera efter förfallodatum",
     "Overdue" : "Förfallen",
+    "Next 24 hours" : "Nästa 24 timmar",
     "Next 7 days" : "Nästa 7 dagar",
     "Next 30 days" : "Nästa 30 dagar",
     "No due date" : "Inget slutdatum",
@@ -151,6 +152,7 @@ OC.L10N.register(
     "Edit" : "Redigera",
     "Add a new tag" : "Lägg till en ny tagg",
     "title and color value must be provided" : "titel och färg måste anges",
+    "Add this attachment" : "Lägg till denna bilaga",
     "Delete Attachment" : "Ta bort bilaga",
     "Restore Attachment" : "Återställ bilaga",
     "Assign a tag to this card…" : "Tilldela en tagg till det här kortet ...",
@@ -164,8 +166,12 @@ OC.L10N.register(
     "(Unsaved)" : "(Inte sparad)",
     "(Saving…)" : "(Sparar…)",
     "Formatting help" : "Formatteringshjälp",
+    "Add Attachment" : "Lägg till bilaga",
+    "Edit description" : "Ändra beskrivning",
+    "View description" : "Visa beskrivning",
     "Attachments" : "Bilagor",
     "Comments" : "Kommentarer",
+    "Choose attachment" : "Välj bilaga",
     "Modified" : "Ändrad",
     "Created" : "Skapat",
     "Upload attachment" : "Ladda upp bilaga",
@@ -178,24 +184,28 @@ OC.L10N.register(
     "Update" : "Uppdatera",
     "(group)" : " (grupp)",
     "(circle)" : "(cirkel)",
+    "seconds ago" : "sekunder sedan",
     "Assign to me" : "Tilldela till mig",
     "Delete card" : "Ta bort kort",
     "Move card" : "Flytta kort",
     "Card details" : "Kortdetaljer",
     "Select a stack" : "Välj en stapel",
-    "seconds ago" : "sekunder sedan",
     "All boards" : "Alla tavlor",
     "Archived boards" : "Arkiverade tavlor",
     "Shared boards" : "Delade tavlor",
     "Settings" : "Inställningar",
+    "Limit deck usage of groups" : "Begränsa användningen av grupper",
     "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "Begränsa Deck blockerar användare som inte ingår i dessa grupper från att skapa egna tavlor. Användare kan fortfarande arbeta med tavlor som har delats med dem.",
     "New board title" : "Ny titel för tavla",
     "Share" : "Dela",
+    "Options" : "Alternativ",
     "Edit board" : "Ändra tavla",
     "An error occurred" : "Ett fel uppstod",
     "Clone board" : "Kopiera tavla",
     "Archive board" : "Arkivera tavla",
     "Unarchive board" : "Ta bort tavlan ur arkivet",
+    "Are you sure you want to delete the board {title}? This will delete all the data of this board." : "Är du säker på att du vill radera tavla {title}? Detta kommer att radera all information från denna tavla.",
+    "Delete the board?" : "Radera tavlan?",
     "Delete board" : "Ta bort tavla",
     "Board details" : "Taveldetaljer",
     "Link to a board" : "Länka till en tavla",
