@@ -5,21 +5,19 @@ OC.L10N.register(
     "Done" : "Done",
     "No file was uploaded" : "ھېچقانداق ھۆججەت يۈكلەنمىدى",
     "Missing a temporary folder" : "ۋاقىتلىق قىسقۇچ كەم.",
-    "Actions" : "مەشغۇلاتلار",
-    "Close" : "ياپ",
+    "Cancel" : "ۋاز كەچ",
     "Sharing" : "ھەمبەھىر",
     "Tags" : "بەلگەلەر",
-    "Group" : "Group",
-    "Loading" : "Loading",
+    "Can edit" : "Can edit",
+    "Can share" : "Can share",
+    "Delete" : "ئۆچۈر",
     "Edit" : "تەھرىر",
-    "Share" : "ھەمبەھىر",
-    "Create" : "قۇر",
-    "Title" : "ماۋزۇ",
-    "Cancel upload" : "يۈكلەشتىن ۋاز كەچ",
-    "by" : "سەنئەتكار",
-    "Modified:" : "ئۆزگەرتكەن ۋاقىت:",
-    "Created:" : "قۇرۇلغان ۋاقتى:",
     "Description" : "چۈشەندۈرۈش",
-    "Settings" : "تەڭشەكلەر"
+    "Modified" : "ئۆزگەرتكەن",
+    "Save" : "ساقلا",
+    "Reply" : "جاۋاب قايتۇر",
+    "Update" : "يېڭىلا",
+    "Settings" : "تەڭشەكلەر",
+    "Share" : "ھەمبەھىر"
 },
 "nplurals=1; plural=0;");
