@@ -32,6 +32,8 @@ OC.L10N.register(
     "Delete list" : "Вилучити список",
     "Add card" : "Додати картку",
     "Edit" : "Редагувати",
+    "Title" : "Назва",
+    "Members" : "Учасники",
     "Due date" : "Протягом",
     "Remove due date" : "Видалити до",
     "Description" : "Опис",
@@ -39,13 +41,14 @@ OC.L10N.register(
     "Attachments" : "Вкладення",
     "Comments" : "Коментарі",
     "Modified" : "Змінено",
+    "Upload attachment" : "Завантажити вкладення",
     "Save" : "Зберегти",
     "Reply" : "Відповісти",
     "Update" : "Оновлення",
     "(group)" : "(група)",
+    "seconds ago" : "секунд тому",
     "Delete card" : "Видалити картку",
     "Move card" : "Пересунути картку",
-    "seconds ago" : "секунд тому",
     "Archived boards" : "Архівовані дошки",
     "Shared boards" : "Спільні дошки",
     "Settings" : "Налаштування",
