@@ -150,6 +150,8 @@ OC.L10N.register(
     "Add a new card" : "添加一张新卡片",
     "Edit" : "编辑",
     "title and color value must be provided" : "必须提供标题和颜色值",
+    "Title" : "标题",
+    "Members" : "会员",
     "Delete Attachment" : "删除附件",
     "Restore Attachment" : "恢复附件",
     "Assign a tag to this card…" : "为该卡片分配标签…",
@@ -173,12 +175,12 @@ OC.L10N.register(
     "Reply" : "回复",
     "Update" : "更新",
     "(group)" : "（组）",
+    "seconds ago" : "几秒前",
     "Assign to me" : "指派给我",
     "Delete card" : "删除卡片",
     "Move card" : "移动卡片",
     "Card details" : "卡片详情",
     "Select a stack" : "选择一个任务",
-    "seconds ago" : "几秒前",
     "All boards" : "全部面板",
     "Archived boards" : "已归档面板",
     "Shared boards" : "已共享面板",
